name = "loxws"

from .miniserver import Miniserver
from .loxdimmer import LoxDimmer
from .loxswitch import LoxSwitch
from .loxlightcontrollerv2 import LoxLightControllerV2
from .loxcolorpickerv2 import LoxColorPickerV2
from .loxiroomcontrollerv2 import LoxIntelligentRoomControllerV2
from .loxclimatecontroller import LoxClimateController
from .loxinfoonlyanalog import LoxInfoOnlyAnalog
from .loxinfoonlydigital import LoxInfoOnlyDigital
from .loxjalousie import LoxJalousie
from .loxmeter import LoxMeter
from .loxpresencedetector import LoxPresenceDetector
from .loxalarmclock import LoxAlarmClock
from .loxwindow import LoxWindow
from .loxgate import LoxGate
